@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -211,7 +211,27 @@ class LcicClient(AbstractClient):
 
 
     def BindDocumentToRoom(self, request):
-        """绑定文档到房间
+        """功能概述
+        本接口提供教学场景下的课程文档预绑定能力，支持将课件课堂ID进行关联映射，实现课件的自动化预加载。
+
+        应用场景建议
+
+        绑定时机
+        推荐在创建课堂预约阶段同步完成文档绑定操作，确保课件资源在课堂开始前完成上传。
+
+        接口限制与频控策略
+
+        频控维度
+        开发者账号维度限频
+        默认频控阈值为20 QPS（每秒请求次数）
+
+        最佳实践建议
+
+        重试策略
+        当触发限频错误时，建议采用以下策略：
+        启用退避重试机制（建议使用指数退避算法）
+        初始重试间隔不低于500ms
+        最大重试次数不超过3次
 
         :param request: Request instance for BindDocumentToRoom.
         :type request: :class:`tencentcloud.lcic.v20220817.models.BindDocumentToRoomRequest`
@@ -303,7 +323,7 @@ class LcicClient(AbstractClient):
 
 
     def CreateRoom(self, request):
-        """创建房间
+        """创建课堂
 
         :param request: Request instance for CreateRoom.
         :type request: :class:`tencentcloud.lcic.v20220817.models.CreateRoomRequest`
@@ -532,6 +552,29 @@ class LcicClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteWhiteBoardSnapshot(self, request):
+        """删除白板板书截图
+
+        :param request: Request instance for DeleteWhiteBoardSnapshot.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.DeleteWhiteBoardSnapshotRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.DeleteWhiteBoardSnapshotResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteWhiteBoardSnapshot", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteWhiteBoardSnapshotResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAnswerList(self, request):
         """获取房间答题详情
 
@@ -856,6 +899,29 @@ class LcicClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeRecordTask(self, request):
+        """查询录制任务ID
+
+        :param request: Request instance for DescribeRecordTask.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.DescribeRecordTaskRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.DescribeRecordTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeRecordTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeRecordTaskResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeRoom(self, request):
         """获取房间配置信息
 
@@ -1017,6 +1083,29 @@ class LcicClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeWhiteBoardSnapshot(self, request):
+        """查询白板板书截图
+
+        :param request: Request instance for DescribeWhiteBoardSnapshot.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.DescribeWhiteBoardSnapshotRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.DescribeWhiteBoardSnapshotResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeWhiteBoardSnapshot", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeWhiteBoardSnapshotResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def EndRoom(self, request):
         """结束房间的直播
 
